pub fn active_rows(dataset: &Dataset) -> &[LabeledSample]Expand description
Returns the canonical active row view used by all fold indices.
pub fn active_rows(dataset: &Dataset) -> &[LabeledSample]Returns the canonical active row view used by all fold indices.